# Grade Conversion Calculator

[![Build Status](https://github.com/uw-it-aca/grade-conversion-calculator/workflows/tests/badge.svg?branch=main)](https://github.com/uw-it-aca/grade-conversion-calculator/actions)
[![Coverage Status](https://coveralls.io/repos/github/uw-it-aca/grade-conversion-calculator/badge.svg?branch=main)](https://coveralls.io/github/uw-it-aca/grade-conversion-calculator?branch=main)
[![PyPi Version](https://img.shields.io/pypi/v/uw-grade-conversion-calculator.svg)](https://pypi.python.org/pypi/uw-grade-conversion-calculator)
![Python version](https://img.shields.io/badge/python-3.10-blue.svg)

Client-side app for converting a percentage-based grading scale to a points-based scale.
